@@ -37,11 +37,7 @@
 #include <sched.h>
 
 #if defined(__APPLE__)
-  /* macOS 10.8 and later have a working posix_spawn */
-# if MAC_OS_X_VERSION_MIN_REQUIRED >= 1080
-#  define UV_USE_APPLE_POSIX_SPAWN
-#  include <spawn.h>
-# endif
+# include <spawn.h>
 # include <paths.h>
 # include <sys/kauth.h>
 # include <sys/types.h>
@@ -434,7 +430,7 @@ static void uv__process_child_init(const uv_process_options_t* options,
 #endif
 
 
-#if defined(UV_USE_APPLE_POSIX_SPAWN)
+#if defined(__APPLE__)
 typedef struct uv__posix_spawn_fncs_tag {
   struct {
     int (*addchdir_np)(const posix_spawn_file_actions_t *, const char *);
@@ -886,7 +882,7 @@ static int uv__spawn_and_init_child(
   int exec_errorno;
   ssize_t r;
 
-#if defined(UV_USE_APPLE_POSIX_SPAWN)
+#if defined(__APPLE__)
   uv_once(&posix_spawn_init_once, uv__spawn_init_posix_spawn);
 
   /* Special child process spawn case for macOS Big Sur (11.0) onwards
